@@ -5,8 +5,8 @@ import pandas as pd
 import json
 import calendar
 from datetime import datetime
-from utils._helpers import _parse_date
-from utils._helpers import _parse_interval
+from kucoincli.utils._helpers import _parse_date
+from kucoincli.utils._helpers import _parse_interval
 import warnings
 import logging
 import sys
